@@ -77,9 +77,8 @@ class ConditionStep(Step):
         self.if_steps = if_steps or []
         self.else_steps = else_steps or []
 
-        root_path = f"Steps.{name}"
-        root_prop = Properties(path=root_path)
-        root_prop.__dict__["Outcome"] = Properties(f"{root_path}.Outcome")
+        root_prop = Properties(step_name=name)
+        root_prop.__dict__["Outcome"] = Properties(step_name=name, path="Outcome")
         self._properties = root_prop
 
     @property
@@ -91,6 +90,11 @@ class ConditionStep(Step):
             ElseSteps=list_to_request(self.else_steps),
         )
 
+    @property
+    def step_only_arguments(self):
+        """Argument dict pertaining to the step only, and not the `if_steps` or `else_steps`."""
+        return self.conditions
+
     @property
     def properties(self):
         """A simple Properties object with `Outcome` as the only property"""
@@ -126,5 +130,10 @@ class JsonGet(PipelineVariable):  # pragma: no cover
             }
         }
 
+    @property
+    def _referenced_steps(self) -> List[str]:
+        """List of step names that this function depends on."""
+        return [self.step.name]
+
 
 JsonGet = deprecated_class(JsonGet, "JsonGet")
