@@ -17,6 +17,8 @@ but use of functools.partial doesn't set correct metadata/type information.
 """
 from __future__ import absolute_import
 
+import abc
+
 from enum import Enum
 from typing import Dict, List, Union
 
@@ -33,6 +35,7 @@ from sagemaker.workflow.entities import (
 from sagemaker.workflow.execution_variables import ExecutionVariable
 from sagemaker.workflow.parameters import Parameter
 from sagemaker.workflow.properties import Properties
+from sagemaker.workflow.entities import PipelineVariable
 
 # TODO: consider base class for those with an expr method, rather than defining a type here
 ConditionValueType = Union[ExecutionVariable, Parameter, Properties]
@@ -61,6 +64,11 @@ class Condition(Entity):
 
     condition_type: ConditionTypeEnum = attr.ib(factory=ConditionTypeEnum.factory)
 
+    @property
+    @abc.abstractmethod
+    def _referenced_steps(self) -> List[str]:
+        """List of step names that this function depends on."""
+
 
 @attr.s
 class ConditionComparison(Condition):
@@ -84,6 +92,16 @@ class ConditionComparison(Condition):
             "RightValue": primitive_or_expr(self.right),
         }
 
+    @property
+    def _referenced_steps(self) -> List[str]:
+        """List of step names that this function depends on."""
+        steps = []
+        if isinstance(self.left, PipelineVariable):
+            steps.extend(self.left._referenced_steps)
+        if isinstance(self.right, PipelineVariable):
+            steps.extend(self.right._referenced_steps)
+        return steps
+
 
 class ConditionEquals(ConditionComparison):
     """A condition for equality comparisons."""
@@ -213,6 +231,17 @@ class ConditionIn(Condition):
             "Values": [primitive_or_expr(in_value) for in_value in self.in_values],
         }
 
+    @property
+    def _referenced_steps(self) -> List[str]:
+        """List of step names that this function depends on."""
+        steps = []
+        if isinstance(self.value, PipelineVariable):
+            steps.extend(self.value._referenced_steps)
+        for in_value in self.in_values:
+            if isinstance(in_value, PipelineVariable):
+                steps.extend(in_value._referenced_steps)
+        return steps
+
 
 class ConditionNot(Condition):
     """A condition for negating another `Condition`."""
@@ -230,6 +259,11 @@ class ConditionNot(Condition):
         """Get the request structure for workflow service calls."""
         return {"Type": self.condition_type.value, "Expression": self.expression.to_request()}
 
+    @property
+    def _referenced_steps(self) -> List[str]:
+        """List of step names that this function depends on."""
+        return self.expression._referenced_steps
+
 
 class ConditionOr(Condition):
     """A condition for taking the logical OR of a list of `Condition` instances."""
@@ -250,6 +284,14 @@ class ConditionOr(Condition):
             "Conditions": [condition.to_request() for condition in self.conditions],
         }
 
+    @property
+    def _referenced_steps(self) -> List[str]:
+        """List of step names that this function depends on."""
+        steps = []
+        for condition in self.conditions:
+            steps.extend(condition._referenced_steps)
+        return steps
+
 
 def primitive_or_expr(
     value: Union[ExecutionVariable, Expression, PrimitiveType, Parameter, Properties]
